@@ -28,19 +28,26 @@ def extract_connects(model_name, connects_raw):
     :param connects_raw:
     :return:
     """
+    def handle_connect(connect):
+        to_ = make_qualified_name(model_name,connect["@to"])
+        from_ = make_qualified_name(model_name, connect["@from"])
+        return {sanitizeName(to_.lower()): sanitizeName(from_.lower())}
+
+    def make_qualified_name(model_name,element_name):
+        qualified_name = ""
+        if "." in element_name or model_name == "":
+            qualified_name = element_name if element_name[0]!='.' else element_name[1:]
+        else:
+            qualified_name = model_name + "." + element_name
+        return qualified_name
 
     connects = {}
     if type(connects_raw) == OrderedDict:
-        to_ = connects_raw["@to"] if not "." in connects_raw["@to"] else model_name + "." + connects_raw["@to"]
-        from_ = connects_raw["@from"] if not "." in connects_raw["@from"] else model_name + "." + connects_raw["@from"]
-
-        return {sanitizeName(to_.lower()): sanitizeName(from_.lower())}
+        return handle_connect(connects_raw)
 
     elif type(connects_raw) == list:
         for connect in connects_raw:
-            to_ = connect["@to"] if not "." in connect["@to"] else model_name + "." + connect["@to"]
-            from_ = connect["@from"] if not "." in connect["@from"] else model_name + "." + connect["@from"]
-            connects[(sanitizeName(to_.lower()) )] =  sanitizeName(from_)
+            connects.update(handle_connect(connect))
 
     return connects
 
@@ -184,6 +191,11 @@ def parse_xmile(filename):
     specs = document["xmile"]["sim_specs"]
     header = document["xmile"]["header"]
 
+    ## ensure starttime and stoptime are floats
+
+    specs["start"] = specs["start"]+".0" if '.' not in specs["start"] else specs["start"]
+    specs["stop"]= specs["stop"]+".0" if '.' not in specs["stop"] else specs["stop"]
+
     ## Delta T (DT)
     try:
         if "@reciprocal" in specs["dt"].keys() and specs["dt"]["@reciprocal"].lower() == 'true': ## Reciprocal values
@@ -272,13 +284,7 @@ def parse_xmile(filename):
     for name, model in IR["models"].items():
         for entity_type, entity in model["entities"].items():
             for elem in entity:
-
-                #try:
                 elem["equation_parsed"] = [makeExpressionAbsolute(name,visitor.visit(grammar.parse(x)),connects=IR["assignments"],entity=entity,dimensions=IR["dimensions"]) for x in elem["equation"]]
-                #except Exception as e:
-                #    print("Error parsing equation: {}. Skipping!".format(elem["equation"]))
-
-                #    logging.error(e)
 
                 # Handle Non-Negative stocks
                 if elem["non_negative"]:
