@@ -1,10 +1,12 @@
 from copy import deepcopy
 
+
 def resolve(expression, entity):
     '''
     This function traverses the AST and replaces the dimensions by the label by the entity's name
     '''
 
+
     if type(expression) is str or type(expression) is float:
         return expression
 
@@ -26,7 +28,15 @@ def resolve(expression, entity):
                     expression["name"] = deepcopy(label_[dimensions_.index(name_)])
 
         if "args" in expression.keys():
-            expression["args"] = resolve(expression["args"], entity)
+
+            try:
+                args = deepcopy(expression["args"])
+                expression["args"] = resolve(args, entity)
+            except RecursionError as e:
+                print("Recursion error for entity '{}'".format(entity["name"]))
+
+                #raise e
+
 
         return expression
     return expression
